/****************************************************************************
** Meta object code from reading C++ file 'systrayx.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/systrayx.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systrayx.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SysTrayXE_t {};
} // unnamed namespace

template <> constexpr inline auto SysTrayX::qt_create_metaobjectdata<qt_meta_tag_ZN8SysTrayXE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SysTrayX",
        "signalMailCount",
        "",
        "unread_mail",
        "new_mail",
        "signalWriteMessage",
        "message",
        "signalClose",
        "signalConsole",
        "slotMailCount",
        "slotLoadLanguage",
        "locale",
        "slotStartApp",
        "slotCloseApp",
        "slotSelectIconObjectPref",
        "slotSelectIconObject",
        "state",
        "slotAddOnShutdown",
        "slotErrorAddOnShutdown",
        "slotShutdown",
        "slotAbout",
        "slotVersion",
        "version",
        "slotShowHideShortcutChange",
        "slotNewMessage",
        "slotNewMessageFromsChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalMailCount'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'signalWriteMessage'
        QtMocHelpers::SignalData<void(QByteArray)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 6 },
        }}),
        // Signal 'signalClose'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalConsole'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'slotMailCount'
        QtMocHelpers::SlotData<void(int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'slotLoadLanguage'
        QtMocHelpers::SlotData<void(QString)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'slotStartApp'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseApp'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectIconObjectPref'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectIconObject'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'slotAddOnShutdown'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotErrorAddOnShutdown'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShutdown'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAbout'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotVersion'
        QtMocHelpers::SlotData<void(QString)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'slotShowHideShortcutChange'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewMessage'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewMessageFromsChange'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SysTrayX, qt_meta_tag_ZN8SysTrayXE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SysTrayX::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SysTrayXE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SysTrayXE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SysTrayXE_t>.metaTypes,
    nullptr
} };

void SysTrayX::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SysTrayX *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalMailCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->signalWriteMessage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->signalClose(); break;
        case 3: _t->signalConsole((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->slotMailCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->slotLoadLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->slotStartApp(); break;
        case 7: _t->slotCloseApp(); break;
        case 8: _t->slotSelectIconObjectPref(); break;
        case 9: _t->slotSelectIconObject((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->slotAddOnShutdown(); break;
        case 11: _t->slotErrorAddOnShutdown(); break;
        case 12: _t->slotShutdown(); break;
        case 13: _t->slotAbout(); break;
        case 14: _t->slotVersion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->slotShowHideShortcutChange(); break;
        case 16: _t->slotNewMessage(); break;
        case 17: _t->slotNewMessageFromsChange(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SysTrayX::*)(int , int )>(_a, &SysTrayX::signalMailCount, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayX::*)(QByteArray )>(_a, &SysTrayX::signalWriteMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayX::*)()>(_a, &SysTrayX::signalClose, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayX::*)(QString )>(_a, &SysTrayX::signalConsole, 3))
            return;
    }
}

const QMetaObject *SysTrayX::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SysTrayX::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SysTrayXE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SysTrayX::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void SysTrayX::signalMailCount(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void SysTrayX::signalWriteMessage(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SysTrayX::signalClose()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SysTrayX::signalConsole(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
