/********************************************************************************
** Form generated from reading UI file 'aboutdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOG_H
#define UI_ABOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>

QT_BEGIN_NAMESPACE

class Ui_AboutDialog
{
public:
    QGridLayout *gridLayout;
    QFormLayout *formLayout;
    QLabel *header;
    QFrame *line;
    QLabel *VersionLabel;
    QLabel *version;
    QLabel *buildLabel;
    QLabel *build;
    QLabel *hashLabel;
    QLabel *hash;
    QLabel *branchLabel;
    QLabel *branch;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AboutDialog)
    {
        if (AboutDialog->objectName().isEmpty())
            AboutDialog->setObjectName("AboutDialog");
        AboutDialog->resize(284, 186);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/files/icons/SysTray-X.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        AboutDialog->setWindowIcon(icon);
        gridLayout = new QGridLayout(AboutDialog);
        gridLayout->setObjectName("gridLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        header = new QLabel(AboutDialog);
        header->setObjectName("header");
        header->setOpenExternalLinks(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, header);

        line = new QFrame(AboutDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, line);

        VersionLabel = new QLabel(AboutDialog);
        VersionLabel->setObjectName("VersionLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, VersionLabel);

        version = new QLabel(AboutDialog);
        version->setObjectName("version");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, version);

        buildLabel = new QLabel(AboutDialog);
        buildLabel->setObjectName("buildLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, buildLabel);

        build = new QLabel(AboutDialog);
        build->setObjectName("build");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, build);

        hashLabel = new QLabel(AboutDialog);
        hashLabel->setObjectName("hashLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, hashLabel);

        hash = new QLabel(AboutDialog);
        hash->setObjectName("hash");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, hash);

        branchLabel = new QLabel(AboutDialog);
        branchLabel->setObjectName("branchLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, branchLabel);

        branch = new QLabel(AboutDialog);
        branch->setObjectName("branch");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, branch);


        gridLayout->addLayout(formLayout, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(AboutDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);


        retranslateUi(AboutDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AboutDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AboutDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *AboutDialog)
    {
        AboutDialog->setWindowTitle(QCoreApplication::translate("AboutDialog", "About SysTray-X", nullptr));
        header->setText(QCoreApplication::translate("AboutDialog", "<a href=\"https://github.com/Ximi1970/systray-x\">SysTray-X</a> Companion App by Ximi1970", nullptr));
        VersionLabel->setText(QCoreApplication::translate("AboutDialog", "Version:", nullptr));
        version->setText(QCoreApplication::translate("AboutDialog", "0.0.1", nullptr));
        buildLabel->setText(QCoreApplication::translate("AboutDialog", "Build:", nullptr));
        build->setText(QCoreApplication::translate("AboutDialog", "0", nullptr));
        hashLabel->setText(QCoreApplication::translate("AboutDialog", "Hash:", nullptr));
        hash->setText(QCoreApplication::translate("AboutDialog", "0", nullptr));
        branchLabel->setText(QCoreApplication::translate("AboutDialog", "Branch:", nullptr));
        branch->setText(QCoreApplication::translate("AboutDialog", "master", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTDIALOG_H
