/****************************************************************************
** Meta object code from reading C++ file 'preferencesdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/preferencesdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'preferencesdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PreferencesDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto PreferencesDialog::qt_create_metaobjectdata<qt_meta_tag_ZN17PreferencesDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PreferencesDialog",
        "signalConsole",
        "",
        "message",
        "signalUpdateSysTrayIcon",
        "signalPreferencesChanged",
        "slotShowDialog",
        "slotDebugChange",
        "slotMinimizeTypeChange",
        "slotMinimizeIconTypeChange",
        "slotStartupTypeChange",
        "slotWindowPositionsCorrectionChange",
        "slotWindowPositionsCorrectionTypeChange",
        "slotRestoreWindowPositionsChange",
        "slotCloseTypeChange",
        "slotIconTypeChange",
        "slotDefaultIconTypeChange",
        "slotHideDefaultIconChange",
        "slotIconDataChange",
        "slotDefaultIconDataChange",
        "slotInvertIconChange",
        "slotCountTypeChange",
        "slotStartupDelayChange",
        "slotApiCountMethodChange",
        "slotShowNumberChange",
        "slotShowNewIndicatorChange",
        "slotNumberColorChange",
        "slotNumberSizeChange",
        "slotNumberAlignmentChange",
        "slotNumberMarginsChange",
        "slotNewIndicatorTypeChange",
        "slotNewShadeColorChange",
        "slotStartAppChange",
        "slotStartAppArgsChange",
        "slotCloseAppChange",
        "slotCloseAppArgsChange",
        "slotShowHideShortcutChange",
        "slotAccept",
        "slotReject",
        "slotFileSelect",
        "slotDefaultFileSelect",
        "slotColorSelect",
        "slotNewShadeColorSelect",
        "slotStartAppSelect",
        "slotCloseAppSelect",
        "slotTruncateShowHideShortcut",
        "slotClearShowHideShortcut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalConsole'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'signalUpdateSysTrayIcon'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalPreferencesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowDialog'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDebugChange'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMinimizeTypeChange'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMinimizeIconTypeChange'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartupTypeChange'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowPositionsCorrectionChange'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowPositionsCorrectionTypeChange'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRestoreWindowPositionsChange'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseTypeChange'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIconTypeChange'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefaultIconTypeChange'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHideDefaultIconChange'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIconDataChange'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefaultIconDataChange'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvertIconChange'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCountTypeChange'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartupDelayChange'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApiCountMethodChange'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowNumberChange'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowNewIndicatorChange'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberColorChange'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberSizeChange'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberAlignmentChange'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberMarginsChange'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewIndicatorTypeChange'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewShadeColorChange'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartAppChange'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartAppArgsChange'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseAppChange'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseAppArgsChange'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowHideShortcutChange'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAccept'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReject'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileSelect'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDefaultFileSelect'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorSelect'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewShadeColorSelect'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStartAppSelect'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCloseAppSelect'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTruncateShowHideShortcut'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearShowHideShortcut'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PreferencesDialog, qt_meta_tag_ZN17PreferencesDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PreferencesDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PreferencesDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PreferencesDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PreferencesDialogE_t>.metaTypes,
    nullptr
} };

void PreferencesDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PreferencesDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalConsole((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->signalUpdateSysTrayIcon(); break;
        case 2: _t->signalPreferencesChanged(); break;
        case 3: _t->slotShowDialog(); break;
        case 4: _t->slotDebugChange(); break;
        case 5: _t->slotMinimizeTypeChange(); break;
        case 6: _t->slotMinimizeIconTypeChange(); break;
        case 7: _t->slotStartupTypeChange(); break;
        case 8: _t->slotWindowPositionsCorrectionChange(); break;
        case 9: _t->slotWindowPositionsCorrectionTypeChange(); break;
        case 10: _t->slotRestoreWindowPositionsChange(); break;
        case 11: _t->slotCloseTypeChange(); break;
        case 12: _t->slotIconTypeChange(); break;
        case 13: _t->slotDefaultIconTypeChange(); break;
        case 14: _t->slotHideDefaultIconChange(); break;
        case 15: _t->slotIconDataChange(); break;
        case 16: _t->slotDefaultIconDataChange(); break;
        case 17: _t->slotInvertIconChange(); break;
        case 18: _t->slotCountTypeChange(); break;
        case 19: _t->slotStartupDelayChange(); break;
        case 20: _t->slotApiCountMethodChange(); break;
        case 21: _t->slotShowNumberChange(); break;
        case 22: _t->slotShowNewIndicatorChange(); break;
        case 23: _t->slotNumberColorChange(); break;
        case 24: _t->slotNumberSizeChange(); break;
        case 25: _t->slotNumberAlignmentChange(); break;
        case 26: _t->slotNumberMarginsChange(); break;
        case 27: _t->slotNewIndicatorTypeChange(); break;
        case 28: _t->slotNewShadeColorChange(); break;
        case 29: _t->slotStartAppChange(); break;
        case 30: _t->slotStartAppArgsChange(); break;
        case 31: _t->slotCloseAppChange(); break;
        case 32: _t->slotCloseAppArgsChange(); break;
        case 33: _t->slotShowHideShortcutChange(); break;
        case 34: _t->slotAccept(); break;
        case 35: _t->slotReject(); break;
        case 36: _t->slotFileSelect(); break;
        case 37: _t->slotDefaultFileSelect(); break;
        case 38: _t->slotColorSelect(); break;
        case 39: _t->slotNewShadeColorSelect(); break;
        case 40: _t->slotStartAppSelect(); break;
        case 41: _t->slotCloseAppSelect(); break;
        case 42: _t->slotTruncateShowHideShortcut(); break;
        case 43: _t->slotClearShowHideShortcut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PreferencesDialog::*)(QString )>(_a, &PreferencesDialog::signalConsole, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesDialog::*)()>(_a, &PreferencesDialog::signalUpdateSysTrayIcon, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesDialog::*)()>(_a, &PreferencesDialog::signalPreferencesChanged, 2))
            return;
    }
}

const QMetaObject *PreferencesDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PreferencesDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PreferencesDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int PreferencesDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void PreferencesDialog::signalConsole(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PreferencesDialog::signalUpdateSysTrayIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PreferencesDialog::signalPreferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
