/****************************************************************************
** Meta object code from reading C++ file 'systrayxlink.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/systrayxlink.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systrayxlink.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18SysTrayXLinkReaderE_t {};
} // unnamed namespace

template <> constexpr inline auto SysTrayXLinkReader::qt_create_metaobjectdata<qt_meta_tag_ZN18SysTrayXLinkReaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SysTrayXLinkReader",
        "signalReceivedMessage",
        "",
        "message",
        "signalErrorAddOnShutdown",
        "startThread",
        "slotWorker"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalReceivedMessage'
        QtMocHelpers::SignalData<void(QByteArray)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'signalErrorAddOnShutdown'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startThread'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWorker'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SysTrayXLinkReader, qt_meta_tag_ZN18SysTrayXLinkReaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SysTrayXLinkReader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SysTrayXLinkReaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SysTrayXLinkReaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SysTrayXLinkReaderE_t>.metaTypes,
    nullptr
} };

void SysTrayXLinkReader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SysTrayXLinkReader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalReceivedMessage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 1: _t->signalErrorAddOnShutdown(); break;
        case 2: _t->startThread(); break;
        case 3: _t->slotWorker(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLinkReader::*)(QByteArray )>(_a, &SysTrayXLinkReader::signalReceivedMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLinkReader::*)()>(_a, &SysTrayXLinkReader::signalErrorAddOnShutdown, 1))
            return;
    }
}

const QMetaObject *SysTrayXLinkReader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SysTrayXLinkReader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SysTrayXLinkReaderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SysTrayXLinkReader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SysTrayXLinkReader::signalReceivedMessage(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SysTrayXLinkReader::signalErrorAddOnShutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN12SysTrayXLinkE_t {};
} // unnamed namespace

template <> constexpr inline auto SysTrayXLink::qt_create_metaobjectdata<qt_meta_tag_ZN12SysTrayXLinkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SysTrayXLink",
        "signalConsole",
        "",
        "message",
        "signalTitle",
        "title",
        "signalVersion",
        "version",
        "signalAddOnShutdown",
        "signalErrorAddOnShutdown",
        "signalWindowState",
        "Preferences::WindowState",
        "state",
        "id",
        "signalKdeIntegration",
        "signalLocale",
        "locale",
        "signalMailCount",
        "unread_mail",
        "new_mail",
        "signalWindowPositions",
        "QList<QPoint>",
        "window_positions",
        "signalStartApp",
        "signalCloseApp",
        "signalNewWindow",
        "signalCloseWindow",
        "quit",
        "slotPositions",
        "positions",
        "slotPreferencesChanged",
        "slotLinkRead",
        "slotErrorAddOnShutdown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalConsole'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'signalTitle'
        QtMocHelpers::SignalData<void(QString)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'signalVersion'
        QtMocHelpers::SignalData<void(QString)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'signalAddOnShutdown'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalErrorAddOnShutdown'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalWindowState'
        QtMocHelpers::SignalData<void(Preferences::WindowState, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'signalKdeIntegration'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'signalLocale'
        QtMocHelpers::SignalData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'signalMailCount'
        QtMocHelpers::SignalData<void(int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'signalWindowPositions'
        QtMocHelpers::SignalData<void(QList<QPoint>)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'signalStartApp'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalCloseApp'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNewWindow'
        QtMocHelpers::SignalData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'signalCloseWindow'
        QtMocHelpers::SignalData<void(int, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'slotPositions'
        QtMocHelpers::SlotData<void(QList<QPoint>)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 29 },
        }}),
        // Slot 'slotPreferencesChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLinkRead'
        QtMocHelpers::SlotData<void(QByteArray)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Slot 'slotErrorAddOnShutdown'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SysTrayXLink, qt_meta_tag_ZN12SysTrayXLinkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SysTrayXLink::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SysTrayXLinkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SysTrayXLinkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SysTrayXLinkE_t>.metaTypes,
    nullptr
} };

void SysTrayXLink::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SysTrayXLink *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalConsole((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->signalTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->signalVersion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->signalAddOnShutdown(); break;
        case 4: _t->signalErrorAddOnShutdown(); break;
        case 5: _t->signalWindowState((*reinterpret_cast<std::add_pointer_t<Preferences::WindowState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->signalKdeIntegration((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->signalLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->signalMailCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->signalWindowPositions((*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[1]))); break;
        case 10: _t->signalStartApp(); break;
        case 11: _t->signalCloseApp(); break;
        case 12: _t->signalNewWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->signalCloseWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->slotPositions((*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[1]))); break;
        case 15: _t->slotPreferencesChanged(); break;
        case 16: _t->slotLinkRead((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 17: _t->slotErrorAddOnShutdown(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(QString )>(_a, &SysTrayXLink::signalConsole, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(QString )>(_a, &SysTrayXLink::signalTitle, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(QString )>(_a, &SysTrayXLink::signalVersion, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)()>(_a, &SysTrayXLink::signalAddOnShutdown, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)()>(_a, &SysTrayXLink::signalErrorAddOnShutdown, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(Preferences::WindowState , int )>(_a, &SysTrayXLink::signalWindowState, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(bool )>(_a, &SysTrayXLink::signalKdeIntegration, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(QString )>(_a, &SysTrayXLink::signalLocale, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(int , int )>(_a, &SysTrayXLink::signalMailCount, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(QList<QPoint> )>(_a, &SysTrayXLink::signalWindowPositions, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)()>(_a, &SysTrayXLink::signalStartApp, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)()>(_a, &SysTrayXLink::signalCloseApp, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(int )>(_a, &SysTrayXLink::signalNewWindow, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SysTrayXLink::*)(int , bool )>(_a, &SysTrayXLink::signalCloseWindow, 13))
            return;
    }
}

const QMetaObject *SysTrayXLink::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SysTrayXLink::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SysTrayXLinkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SysTrayXLink::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void SysTrayXLink::signalConsole(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SysTrayXLink::signalTitle(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SysTrayXLink::signalVersion(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SysTrayXLink::signalAddOnShutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SysTrayXLink::signalErrorAddOnShutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SysTrayXLink::signalWindowState(Preferences::WindowState _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void SysTrayXLink::signalKdeIntegration(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SysTrayXLink::signalLocale(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void SysTrayXLink::signalMailCount(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void SysTrayXLink::signalWindowPositions(QList<QPoint> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void SysTrayXLink::signalStartApp()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SysTrayXLink::signalCloseApp()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void SysTrayXLink::signalNewWindow(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void SysTrayXLink::signalCloseWindow(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}
QT_WARNING_POP
