/********************************************************************************
** Form generated from reading UI file 'debugwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGWIDGET_H
#define UI_DEBUGWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DebugWidget
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *unreadMailTextLabel;
    QLabel *unreadMailLabel;
    QHBoxLayout *horizontalLayout_3;
    QLabel *newMailTextLabel;
    QLabel *newMailLabel;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer;
    QTextEdit *textEdit;
    QHBoxLayout *horizontalLayout;
    QPushButton *test1PushButton;
    QPushButton *test2PushButton;
    QPushButton *test3PushButton;
    QPushButton *test4PushButton;

    void setupUi(QWidget *DebugWidget)
    {
        if (DebugWidget->objectName().isEmpty())
            DebugWidget->setObjectName("DebugWidget");
        DebugWidget->resize(358, 290);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/files/icons/SysTray-X.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        DebugWidget->setWindowIcon(icon);
        gridLayout = new QGridLayout(DebugWidget);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        unreadMailTextLabel = new QLabel(DebugWidget);
        unreadMailTextLabel->setObjectName("unreadMailTextLabel");

        horizontalLayout_2->addWidget(unreadMailTextLabel);

        unreadMailLabel = new QLabel(DebugWidget);
        unreadMailLabel->setObjectName("unreadMailLabel");

        horizontalLayout_2->addWidget(unreadMailLabel);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        newMailTextLabel = new QLabel(DebugWidget);
        newMailTextLabel->setObjectName("newMailTextLabel");

        horizontalLayout_3->addWidget(newMailTextLabel);

        newMailLabel = new QLabel(DebugWidget);
        newMailLabel->setObjectName("newMailLabel");

        horizontalLayout_3->addWidget(newMailLabel);


        verticalLayout->addLayout(horizontalLayout_3);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(254, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 1);

        textEdit = new QTextEdit(DebugWidget);
        textEdit->setObjectName("textEdit");

        gridLayout->addWidget(textEdit, 2, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        test1PushButton = new QPushButton(DebugWidget);
        test1PushButton->setObjectName("test1PushButton");

        horizontalLayout->addWidget(test1PushButton);

        test2PushButton = new QPushButton(DebugWidget);
        test2PushButton->setObjectName("test2PushButton");

        horizontalLayout->addWidget(test2PushButton);

        test3PushButton = new QPushButton(DebugWidget);
        test3PushButton->setObjectName("test3PushButton");

        horizontalLayout->addWidget(test3PushButton);

        test4PushButton = new QPushButton(DebugWidget);
        test4PushButton->setObjectName("test4PushButton");

        horizontalLayout->addWidget(test4PushButton);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 2);


        retranslateUi(DebugWidget);

        QMetaObject::connectSlotsByName(DebugWidget);
    } // setupUi

    void retranslateUi(QWidget *DebugWidget)
    {
        DebugWidget->setWindowTitle(QCoreApplication::translate("DebugWidget", "SysTray-X Debug", nullptr));
        unreadMailTextLabel->setText(QCoreApplication::translate("DebugWidget", "Unread mail:", nullptr));
        unreadMailLabel->setText(QCoreApplication::translate("DebugWidget", "0", nullptr));
        newMailTextLabel->setText(QCoreApplication::translate("DebugWidget", "New mail:", nullptr));
        newMailLabel->setText(QCoreApplication::translate("DebugWidget", "0", nullptr));
        test1PushButton->setText(QCoreApplication::translate("DebugWidget", "Test 1", nullptr));
        test2PushButton->setText(QCoreApplication::translate("DebugWidget", "Test 2", nullptr));
        test3PushButton->setText(QCoreApplication::translate("DebugWidget", "Test 3", nullptr));
        test4PushButton->setText(QCoreApplication::translate("DebugWidget", "Test 4", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DebugWidget: public Ui_DebugWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGWIDGET_H
