/****************************************************************************
** Meta object code from reading C++ file 'windowctrl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/windowctrl.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'windowctrl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10WindowCtrlE_t {};
} // unnamed namespace

template <> constexpr inline auto WindowCtrl::qt_create_metaobjectdata<qt_meta_tag_ZN10WindowCtrlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WindowCtrl",
        "signalHideDefaultIconChange",
        "",
        "hide",
        "slotWindowTest1",
        "slotWindowTest2",
        "slotWindowTest3",
        "slotWindowTest4",
        "slotMinimizeTypeChange",
        "slotMinimizeIconTypeChange",
        "slotCloseTypeChange",
        "slotWindowState",
        "Preferences::WindowState",
        "state",
        "id",
        "slotShowHide",
        "slotClose",
        "slotPositions",
        "QList<QPoint>",
        "window_positions",
        "slotNewWindow",
        "slotCloseWindow",
        "quit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalHideDefaultIconChange'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'slotWindowTest1'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowTest2'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowTest3'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowTest4'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMinimizeTypeChange'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMinimizeIconTypeChange'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseTypeChange'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowState'
        QtMocHelpers::SlotData<void(Preferences::WindowState, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'slotShowHide'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClose'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPositions'
        QtMocHelpers::SlotData<void(QList<QPoint>)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'slotNewWindow'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'slotCloseWindow'
        QtMocHelpers::SlotData<void(int, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WindowCtrl, qt_meta_tag_ZN10WindowCtrlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WindowCtrl::staticMetaObject = { {
    QMetaObject::SuperData::link<WindowCtrlUnix::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WindowCtrlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WindowCtrlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10WindowCtrlE_t>.metaTypes,
    nullptr
} };

void WindowCtrl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WindowCtrl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalHideDefaultIconChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->slotWindowTest1(); break;
        case 2: _t->slotWindowTest2(); break;
        case 3: _t->slotWindowTest3(); break;
        case 4: _t->slotWindowTest4(); break;
        case 5: _t->slotMinimizeTypeChange(); break;
        case 6: _t->slotMinimizeIconTypeChange(); break;
        case 7: _t->slotCloseTypeChange(); break;
        case 8: _t->slotWindowState((*reinterpret_cast<std::add_pointer_t<Preferences::WindowState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->slotShowHide(); break;
        case 10: _t->slotClose(); break;
        case 11: _t->slotPositions((*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[1]))); break;
        case 12: _t->slotNewWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->slotCloseWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WindowCtrl::*)(bool )>(_a, &WindowCtrl::signalHideDefaultIconChange, 0))
            return;
    }
}

const QMetaObject *WindowCtrl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WindowCtrl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WindowCtrlE_t>.strings))
        return static_cast<void*>(this);
    return WindowCtrlUnix::qt_metacast(_clname);
}

int WindowCtrl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WindowCtrlUnix::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void WindowCtrl::signalHideDefaultIconChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
