/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QKeySequenceEdit>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PreferencesDialog
{
public:
    QGridLayout *gridLayout_14;
    QVBoxLayout *verticalLayout_24;
    QTabWidget *tabWidget;
    QWidget *tabWindows;
    QGridLayout *gridLayout_13;
    QSpacerItem *horizontalSpacer_11;
    QVBoxLayout *verticalLayout_23;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *defaultMinimizeRadioButton;
    QRadioButton *minimizeMethod1RadioButton;
    QRadioButton *minimizeMethod2RadioButton;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_4;
    QRadioButton *defaultMinimizeIconRadioButton;
    QRadioButton *minimizeTrayIconRadioButton;
    QGroupBox *positionGroupBox;
    QVBoxLayout *verticalLayout_22;
    QVBoxLayout *verticalLayout_21;
    QCheckBox *correctWinPosCheckBox;
    QVBoxLayout *verticalLayout_14;
    QRadioButton *noTitlebarCorrectionRadioButton;
    QRadioButton *addTitlebarCorrectionRadioButton;
    QRadioButton *subtractTitlebarCorrectionRadioButton;
    QSpacerItem *verticalSpacer_5;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_15;
    QRadioButton *defaultCloseWindowsRadioButton;
    QRadioButton *minimizeMainTrayCloseChildrenWindowsRadioButton;
    QRadioButton *minimizeAllTrayWindowsRadioButton;
    QRadioButton *minimizeMainCloseChildrenWindowsRadioButton;
    QRadioButton *minimizeAllWindowsRadioButton;
    QGroupBox *groupBox_9;
    QVBoxLayout *verticalLayout_10;
    QRadioButton *startDefaultRadioButton;
    QRadioButton *startMinimizedRadioButton;
    QRadioButton *startDockedRadioButton;
    QCheckBox *restorePositionscheckBox;
    QSpacerItem *verticalSpacer_6;
    QWidget *tabIcon;
    QGridLayout *gridLayout;
    QGroupBox *defaultIconGroupBox;
    QVBoxLayout *verticalLayout_13;
    QGroupBox *iconGroupBox;
    QVBoxLayout *verticalLayout_12;
    QVBoxLayout *verticalLayout_9;
    QRadioButton *defaultIconRadioButton;
    QRadioButton *lookThroughDefaultIconRadioButton;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *customDefaultIconRadioButton;
    QLabel *defaultImageLabel;
    QPushButton *chooseCustomDefaultIconButton;
    QCheckBox *hideDefaultIconCheckBox;
    QGroupBox *iconTypeGroupBox;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *blankIconRadioButton;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *newMailIconRadioButton;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QRadioButton *customIconRadioButton;
    QLabel *imageLabel;
    QPushButton *chooseCustomButton;
    QHBoxLayout *horizontalLayout_8;
    QRadioButton *noIconRadioButton;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_11;
    QRadioButton *tbIconRadioButton;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *invertIconCheckBox;
    QSpacerItem *horizontalSpacer_8;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_4;
    QWidget *tabCount;
    QGridLayout *gridLayout_10;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *showNumberCheckBox;
    QCheckBox *showNewCheckBox;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_3;
    QSpinBox *startupDelaySpinBox;
    QGroupBox *countTypeGroupBox;
    QGridLayout *gridLayout_12;
    QVBoxLayout *verticalLayout_5;
    QRadioButton *unreadRadioButton;
    QRadioButton *newRadioButton;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_6;
    QVBoxLayout *verticalLayout_8;
    QLabel *numberMarginsLabel;
    QHBoxLayout *horizontalLayout_10;
    QSpinBox *numberMarginLeftSpinBox;
    QSpinBox *numberMarginTopSpinBox;
    QSpinBox *numberMarginRightSpinBox;
    QSpinBox *numberMarginBottomSpinBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayoutNumColor;
    QLabel *label;
    QPushButton *numberColorPushButton;
    QHBoxLayout *horizontalLayoutNumSize;
    QLabel *label_2;
    QSpinBox *numberSizeSpinBox;
    QHBoxLayout *horizontalLayoutAlignment;
    QLabel *numberAlignmentLabel;
    QComboBox *numberAlignmentComboBox;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout_20;
    QVBoxLayout *verticalLayout_19;
    QRadioButton *newIconRoundRadioButton;
    QRadioButton *newIconStarRadioButton;
    QHBoxLayout *horizontalLayout_15;
    QRadioButton *newShadeRadioButton;
    QPushButton *newShadeColorPushButton;
    QSpacerItem *horizontalSpacer_9;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_9;
    QSpacerItem *horizontalSpacer_10;
    QGroupBox *specialOptionsGroupBox;
    QGridLayout *gridLayout_8;
    QCheckBox *apiCountMethod;
    QSpacerItem *verticalSpacer_10;
    QWidget *tabApps;
    QGridLayout *gridLayout_11;
    QGridLayout *gridLayout_9;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_5;
    QVBoxLayout *verticalLayout_18;
    QHBoxLayout *horizontalLayout_12;
    QLineEdit *closeAppLineEdit;
    QPushButton *closeBrowseButton;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_5;
    QLineEdit *closeAppArgsLineEdit;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout_17;
    QHBoxLayout *horizontalLayout_14;
    QLineEdit *startAppLineEdit;
    QPushButton *startBrowseButton;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_6;
    QLineEdit *startAppArgsLineEdit;
    QSpacerItem *verticalSpacer_7;
    QWidget *tabMail;
    QGridLayout *gridLayout_4;
    QLabel *label_4;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer;
    QWidget *tabShortcuts;
    QGridLayout *gridLayout_7;
    QVBoxLayout *verticalLayout_16;
    QHBoxLayout *horizontalLayout_18;
    QHBoxLayout *horizontalLayout_16;
    QLabel *label_8;
    QLabel *currentShowHideShortcut;
    QSpacerItem *horizontalSpacer_13;
    QHBoxLayout *horizontalLayout_17;
    QLabel *label_7;
    QKeySequenceEdit *showHideKeySequenceEdit;
    QPushButton *clearShowHideShortcutPushButton;
    QSpacerItem *verticalSpacer_11;
    QWidget *tabDebug;
    QGridLayout *gridLayout_3;
    QCheckBox *debugWindowCheckBox;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_7;
    QPushButton *cancelPushButton;
    QPushButton *savePushButton;
    QButtonGroup *startupTypeGroup;
    QButtonGroup *positionGroup;
    QButtonGroup *minimizeIconTypeGroup;
    QButtonGroup *iconTypeGroup;
    QButtonGroup *defaultIconTypeGroup;
    QButtonGroup *countTypeGroup;
    QButtonGroup *newIndicatorTypeGroup;
    QButtonGroup *minimizeTypeGroup;
    QButtonGroup *closeTypeGroup;

    void setupUi(QDialog *PreferencesDialog)
    {
        if (PreferencesDialog->objectName().isEmpty())
            PreferencesDialog->setObjectName("PreferencesDialog");
        PreferencesDialog->resize(663, 519);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PreferencesDialog->sizePolicy().hasHeightForWidth());
        PreferencesDialog->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/files/icons/SysTray-X.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        PreferencesDialog->setWindowIcon(icon);
        gridLayout_14 = new QGridLayout(PreferencesDialog);
        gridLayout_14->setObjectName("gridLayout_14");
        verticalLayout_24 = new QVBoxLayout();
        verticalLayout_24->setObjectName("verticalLayout_24");
        tabWidget = new QTabWidget(PreferencesDialog);
        tabWidget->setObjectName("tabWidget");
        tabWindows = new QWidget();
        tabWindows->setObjectName("tabWindows");
        gridLayout_13 = new QGridLayout(tabWindows);
        gridLayout_13->setObjectName("gridLayout_13");
        horizontalSpacer_11 = new QSpacerItem(2, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_13->addItem(horizontalSpacer_11, 0, 2, 1, 1);

        verticalLayout_23 = new QVBoxLayout();
        verticalLayout_23->setObjectName("verticalLayout_23");
        groupBox_4 = new QGroupBox(tabWindows);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_3 = new QVBoxLayout(groupBox_4);
        verticalLayout_3->setObjectName("verticalLayout_3");
        defaultMinimizeRadioButton = new QRadioButton(groupBox_4);
        minimizeTypeGroup = new QButtonGroup(PreferencesDialog);
        minimizeTypeGroup->setObjectName("minimizeTypeGroup");
        minimizeTypeGroup->addButton(defaultMinimizeRadioButton);
        defaultMinimizeRadioButton->setObjectName("defaultMinimizeRadioButton");
        defaultMinimizeRadioButton->setChecked(false);

        verticalLayout_3->addWidget(defaultMinimizeRadioButton);

        minimizeMethod1RadioButton = new QRadioButton(groupBox_4);
        minimizeTypeGroup->addButton(minimizeMethod1RadioButton);
        minimizeMethod1RadioButton->setObjectName("minimizeMethod1RadioButton");
        minimizeMethod1RadioButton->setChecked(true);

        verticalLayout_3->addWidget(minimizeMethod1RadioButton);

        minimizeMethod2RadioButton = new QRadioButton(groupBox_4);
        minimizeTypeGroup->addButton(minimizeMethod2RadioButton);
        minimizeMethod2RadioButton->setObjectName("minimizeMethod2RadioButton");

        verticalLayout_3->addWidget(minimizeMethod2RadioButton);


        verticalLayout_23->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(tabWindows);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_4 = new QVBoxLayout(groupBox_5);
        verticalLayout_4->setObjectName("verticalLayout_4");
        defaultMinimizeIconRadioButton = new QRadioButton(groupBox_5);
        minimizeIconTypeGroup = new QButtonGroup(PreferencesDialog);
        minimizeIconTypeGroup->setObjectName("minimizeIconTypeGroup");
        minimizeIconTypeGroup->addButton(defaultMinimizeIconRadioButton);
        defaultMinimizeIconRadioButton->setObjectName("defaultMinimizeIconRadioButton");
        defaultMinimizeIconRadioButton->setChecked(false);

        verticalLayout_4->addWidget(defaultMinimizeIconRadioButton);

        minimizeTrayIconRadioButton = new QRadioButton(groupBox_5);
        minimizeIconTypeGroup->addButton(minimizeTrayIconRadioButton);
        minimizeTrayIconRadioButton->setObjectName("minimizeTrayIconRadioButton");
        minimizeTrayIconRadioButton->setChecked(true);

        verticalLayout_4->addWidget(minimizeTrayIconRadioButton);


        verticalLayout_23->addWidget(groupBox_5);

        positionGroupBox = new QGroupBox(tabWindows);
        positionGroupBox->setObjectName("positionGroupBox");
        verticalLayout_22 = new QVBoxLayout(positionGroupBox);
        verticalLayout_22->setObjectName("verticalLayout_22");
        verticalLayout_21 = new QVBoxLayout();
        verticalLayout_21->setObjectName("verticalLayout_21");
        correctWinPosCheckBox = new QCheckBox(positionGroupBox);
        correctWinPosCheckBox->setObjectName("correctWinPosCheckBox");

        verticalLayout_21->addWidget(correctWinPosCheckBox);

        verticalLayout_14 = new QVBoxLayout();
        verticalLayout_14->setObjectName("verticalLayout_14");
        noTitlebarCorrectionRadioButton = new QRadioButton(positionGroupBox);
        positionGroup = new QButtonGroup(PreferencesDialog);
        positionGroup->setObjectName("positionGroup");
        positionGroup->addButton(noTitlebarCorrectionRadioButton);
        noTitlebarCorrectionRadioButton->setObjectName("noTitlebarCorrectionRadioButton");
        noTitlebarCorrectionRadioButton->setChecked(true);

        verticalLayout_14->addWidget(noTitlebarCorrectionRadioButton);

        addTitlebarCorrectionRadioButton = new QRadioButton(positionGroupBox);
        positionGroup->addButton(addTitlebarCorrectionRadioButton);
        addTitlebarCorrectionRadioButton->setObjectName("addTitlebarCorrectionRadioButton");

        verticalLayout_14->addWidget(addTitlebarCorrectionRadioButton);

        subtractTitlebarCorrectionRadioButton = new QRadioButton(positionGroupBox);
        positionGroup->addButton(subtractTitlebarCorrectionRadioButton);
        subtractTitlebarCorrectionRadioButton->setObjectName("subtractTitlebarCorrectionRadioButton");

        verticalLayout_14->addWidget(subtractTitlebarCorrectionRadioButton);


        verticalLayout_21->addLayout(verticalLayout_14);


        verticalLayout_22->addLayout(verticalLayout_21);


        verticalLayout_23->addWidget(positionGroupBox);

        verticalSpacer_5 = new QSpacerItem(20, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_23->addItem(verticalSpacer_5);


        gridLayout_13->addLayout(verticalLayout_23, 0, 0, 1, 1);

        verticalLayout_11 = new QVBoxLayout();
        verticalLayout_11->setObjectName("verticalLayout_11");
        groupBox_6 = new QGroupBox(tabWindows);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout_15 = new QVBoxLayout(groupBox_6);
        verticalLayout_15->setObjectName("verticalLayout_15");
        defaultCloseWindowsRadioButton = new QRadioButton(groupBox_6);
        closeTypeGroup = new QButtonGroup(PreferencesDialog);
        closeTypeGroup->setObjectName("closeTypeGroup");
        closeTypeGroup->addButton(defaultCloseWindowsRadioButton);
        defaultCloseWindowsRadioButton->setObjectName("defaultCloseWindowsRadioButton");

        verticalLayout_15->addWidget(defaultCloseWindowsRadioButton);

        minimizeMainTrayCloseChildrenWindowsRadioButton = new QRadioButton(groupBox_6);
        closeTypeGroup->addButton(minimizeMainTrayCloseChildrenWindowsRadioButton);
        minimizeMainTrayCloseChildrenWindowsRadioButton->setObjectName("minimizeMainTrayCloseChildrenWindowsRadioButton");
        minimizeMainTrayCloseChildrenWindowsRadioButton->setChecked(true);

        verticalLayout_15->addWidget(minimizeMainTrayCloseChildrenWindowsRadioButton);

        minimizeAllTrayWindowsRadioButton = new QRadioButton(groupBox_6);
        closeTypeGroup->addButton(minimizeAllTrayWindowsRadioButton);
        minimizeAllTrayWindowsRadioButton->setObjectName("minimizeAllTrayWindowsRadioButton");
        minimizeAllTrayWindowsRadioButton->setChecked(false);

        verticalLayout_15->addWidget(minimizeAllTrayWindowsRadioButton);

        minimizeMainCloseChildrenWindowsRadioButton = new QRadioButton(groupBox_6);
        closeTypeGroup->addButton(minimizeMainCloseChildrenWindowsRadioButton);
        minimizeMainCloseChildrenWindowsRadioButton->setObjectName("minimizeMainCloseChildrenWindowsRadioButton");
        minimizeMainCloseChildrenWindowsRadioButton->setChecked(false);

        verticalLayout_15->addWidget(minimizeMainCloseChildrenWindowsRadioButton);

        minimizeAllWindowsRadioButton = new QRadioButton(groupBox_6);
        closeTypeGroup->addButton(minimizeAllWindowsRadioButton);
        minimizeAllWindowsRadioButton->setObjectName("minimizeAllWindowsRadioButton");
        minimizeAllWindowsRadioButton->setChecked(false);

        verticalLayout_15->addWidget(minimizeAllWindowsRadioButton);


        verticalLayout_11->addWidget(groupBox_6);

        groupBox_9 = new QGroupBox(tabWindows);
        groupBox_9->setObjectName("groupBox_9");
        verticalLayout_10 = new QVBoxLayout(groupBox_9);
        verticalLayout_10->setObjectName("verticalLayout_10");
        startDefaultRadioButton = new QRadioButton(groupBox_9);
        startupTypeGroup = new QButtonGroup(PreferencesDialog);
        startupTypeGroup->setObjectName("startupTypeGroup");
        startupTypeGroup->addButton(startDefaultRadioButton);
        startDefaultRadioButton->setObjectName("startDefaultRadioButton");
        startDefaultRadioButton->setChecked(true);

        verticalLayout_10->addWidget(startDefaultRadioButton);

        startMinimizedRadioButton = new QRadioButton(groupBox_9);
        startupTypeGroup->addButton(startMinimizedRadioButton);
        startMinimizedRadioButton->setObjectName("startMinimizedRadioButton");

        verticalLayout_10->addWidget(startMinimizedRadioButton);

        startDockedRadioButton = new QRadioButton(groupBox_9);
        startupTypeGroup->addButton(startDockedRadioButton);
        startDockedRadioButton->setObjectName("startDockedRadioButton");
        startDockedRadioButton->setChecked(false);

        verticalLayout_10->addWidget(startDockedRadioButton);


        verticalLayout_11->addWidget(groupBox_9);

        restorePositionscheckBox = new QCheckBox(tabWindows);
        restorePositionscheckBox->setObjectName("restorePositionscheckBox");

        verticalLayout_11->addWidget(restorePositionscheckBox);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_6);


        gridLayout_13->addLayout(verticalLayout_11, 0, 1, 1, 1);

        tabWidget->addTab(tabWindows, QString());
        tabIcon = new QWidget();
        tabIcon->setObjectName("tabIcon");
        gridLayout = new QGridLayout(tabIcon);
        gridLayout->setObjectName("gridLayout");
        defaultIconGroupBox = new QGroupBox(tabIcon);
        defaultIconGroupBox->setObjectName("defaultIconGroupBox");
        verticalLayout_13 = new QVBoxLayout(defaultIconGroupBox);
        verticalLayout_13->setObjectName("verticalLayout_13");
        iconGroupBox = new QGroupBox(defaultIconGroupBox);
        iconGroupBox->setObjectName("iconGroupBox");
        verticalLayout_12 = new QVBoxLayout(iconGroupBox);
        verticalLayout_12->setObjectName("verticalLayout_12");
        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setObjectName("verticalLayout_9");
        defaultIconRadioButton = new QRadioButton(iconGroupBox);
        defaultIconTypeGroup = new QButtonGroup(PreferencesDialog);
        defaultIconTypeGroup->setObjectName("defaultIconTypeGroup");
        defaultIconTypeGroup->addButton(defaultIconRadioButton);
        defaultIconRadioButton->setObjectName("defaultIconRadioButton");
        defaultIconRadioButton->setChecked(true);

        verticalLayout_9->addWidget(defaultIconRadioButton);

        lookThroughDefaultIconRadioButton = new QRadioButton(iconGroupBox);
        defaultIconTypeGroup->addButton(lookThroughDefaultIconRadioButton);
        lookThroughDefaultIconRadioButton->setObjectName("lookThroughDefaultIconRadioButton");

        verticalLayout_9->addWidget(lookThroughDefaultIconRadioButton);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        customDefaultIconRadioButton = new QRadioButton(iconGroupBox);
        defaultIconTypeGroup->addButton(customDefaultIconRadioButton);
        customDefaultIconRadioButton->setObjectName("customDefaultIconRadioButton");

        horizontalLayout_4->addWidget(customDefaultIconRadioButton);

        defaultImageLabel = new QLabel(iconGroupBox);
        defaultImageLabel->setObjectName("defaultImageLabel");

        horizontalLayout_4->addWidget(defaultImageLabel);

        chooseCustomDefaultIconButton = new QPushButton(iconGroupBox);
        chooseCustomDefaultIconButton->setObjectName("chooseCustomDefaultIconButton");
        chooseCustomDefaultIconButton->setFlat(false);

        horizontalLayout_4->addWidget(chooseCustomDefaultIconButton);


        verticalLayout_9->addLayout(horizontalLayout_4);


        verticalLayout_12->addLayout(verticalLayout_9);


        verticalLayout_13->addWidget(iconGroupBox);

        hideDefaultIconCheckBox = new QCheckBox(defaultIconGroupBox);
        hideDefaultIconCheckBox->setObjectName("hideDefaultIconCheckBox");
        hideDefaultIconCheckBox->setChecked(false);

        verticalLayout_13->addWidget(hideDefaultIconCheckBox);


        gridLayout->addWidget(defaultIconGroupBox, 0, 0, 1, 1);

        iconTypeGroupBox = new QGroupBox(tabIcon);
        iconTypeGroupBox->setObjectName("iconTypeGroupBox");
        verticalLayout_7 = new QVBoxLayout(iconTypeGroupBox);
        verticalLayout_7->setObjectName("verticalLayout_7");
        groupBox_8 = new QGroupBox(iconTypeGroupBox);
        groupBox_8->setObjectName("groupBox_8");
        verticalLayout = new QVBoxLayout(groupBox_8);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setSizeConstraint(QLayout::SetFixedSize);
        blankIconRadioButton = new QRadioButton(groupBox_8);
        iconTypeGroup = new QButtonGroup(PreferencesDialog);
        iconTypeGroup->setObjectName("iconTypeGroup");
        iconTypeGroup->addButton(blankIconRadioButton);
        blankIconRadioButton->setObjectName("blankIconRadioButton");
        blankIconRadioButton->setChecked(true);

        horizontalLayout_3->addWidget(blankIconRadioButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SetFixedSize);
        newMailIconRadioButton = new QRadioButton(groupBox_8);
        iconTypeGroup->addButton(newMailIconRadioButton);
        newMailIconRadioButton->setObjectName("newMailIconRadioButton");

        horizontalLayout_2->addWidget(newMailIconRadioButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetMaximumSize);
        customIconRadioButton = new QRadioButton(groupBox_8);
        iconTypeGroup->addButton(customIconRadioButton);
        customIconRadioButton->setObjectName("customIconRadioButton");

        horizontalLayout->addWidget(customIconRadioButton);

        imageLabel = new QLabel(groupBox_8);
        imageLabel->setObjectName("imageLabel");

        horizontalLayout->addWidget(imageLabel);

        chooseCustomButton = new QPushButton(groupBox_8);
        chooseCustomButton->setObjectName("chooseCustomButton");
        chooseCustomButton->setFlat(false);

        horizontalLayout->addWidget(chooseCustomButton);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        noIconRadioButton = new QRadioButton(groupBox_8);
        iconTypeGroup->addButton(noIconRadioButton);
        noIconRadioButton->setObjectName("noIconRadioButton");

        horizontalLayout_8->addWidget(noIconRadioButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_8);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        tbIconRadioButton = new QRadioButton(groupBox_8);
        iconTypeGroup->addButton(tbIconRadioButton);
        tbIconRadioButton->setObjectName("tbIconRadioButton");

        horizontalLayout_11->addWidget(tbIconRadioButton);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_5);


        verticalLayout->addLayout(horizontalLayout_11);


        verticalLayout_7->addWidget(groupBox_8);

        invertIconCheckBox = new QCheckBox(iconTypeGroupBox);
        invertIconCheckBox->setObjectName("invertIconCheckBox");

        verticalLayout_7->addWidget(invertIconCheckBox);


        gridLayout->addWidget(iconTypeGroupBox, 0, 1, 2, 1);

        horizontalSpacer_8 = new QSpacerItem(6, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_8, 0, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 80, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 1, 0, 2, 1);

        verticalSpacer_4 = new QSpacerItem(20, 80, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 2, 1, 1, 1);

        tabWidget->addTab(tabIcon, QString());
        tabCount = new QWidget();
        tabCount->setObjectName("tabCount");
        gridLayout_10 = new QGridLayout(tabCount);
        gridLayout_10->setObjectName("gridLayout_10");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName("verticalLayout_6");
        showNumberCheckBox = new QCheckBox(tabCount);
        showNumberCheckBox->setObjectName("showNumberCheckBox");
        showNumberCheckBox->setChecked(true);

        verticalLayout_6->addWidget(showNumberCheckBox);

        showNewCheckBox = new QCheckBox(tabCount);
        showNewCheckBox->setObjectName("showNewCheckBox");

        verticalLayout_6->addWidget(showNewCheckBox);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_3 = new QLabel(tabCount);
        label_3->setObjectName("label_3");

        horizontalLayout_6->addWidget(label_3);

        startupDelaySpinBox = new QSpinBox(tabCount);
        startupDelaySpinBox->setObjectName("startupDelaySpinBox");
        startupDelaySpinBox->setMinimum(0);
        startupDelaySpinBox->setMaximum(99);
        startupDelaySpinBox->setValue(5);

        horizontalLayout_6->addWidget(startupDelaySpinBox);


        verticalLayout_6->addLayout(horizontalLayout_6);


        gridLayout_10->addLayout(verticalLayout_6, 0, 0, 1, 1);

        countTypeGroupBox = new QGroupBox(tabCount);
        countTypeGroupBox->setObjectName("countTypeGroupBox");
        gridLayout_12 = new QGridLayout(countTypeGroupBox);
        gridLayout_12->setObjectName("gridLayout_12");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        unreadRadioButton = new QRadioButton(countTypeGroupBox);
        countTypeGroup = new QButtonGroup(PreferencesDialog);
        countTypeGroup->setObjectName("countTypeGroup");
        countTypeGroup->addButton(unreadRadioButton);
        unreadRadioButton->setObjectName("unreadRadioButton");
        unreadRadioButton->setChecked(true);

        verticalLayout_5->addWidget(unreadRadioButton);

        newRadioButton = new QRadioButton(countTypeGroupBox);
        countTypeGroup->addButton(newRadioButton);
        newRadioButton->setObjectName("newRadioButton");

        verticalLayout_5->addWidget(newRadioButton);


        gridLayout_12->addLayout(verticalLayout_5, 0, 0, 1, 1);


        gridLayout_10->addWidget(countTypeGroupBox, 0, 1, 1, 1);

        groupBox_3 = new QGroupBox(tabCount);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_6 = new QGridLayout(groupBox_3);
        gridLayout_6->setObjectName("gridLayout_6");
        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setObjectName("verticalLayout_8");
        numberMarginsLabel = new QLabel(groupBox_3);
        numberMarginsLabel->setObjectName("numberMarginsLabel");

        verticalLayout_8->addWidget(numberMarginsLabel);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        numberMarginLeftSpinBox = new QSpinBox(groupBox_3);
        numberMarginLeftSpinBox->setObjectName("numberMarginLeftSpinBox");
        numberMarginLeftSpinBox->setMaximum(999);

        horizontalLayout_10->addWidget(numberMarginLeftSpinBox);

        numberMarginTopSpinBox = new QSpinBox(groupBox_3);
        numberMarginTopSpinBox->setObjectName("numberMarginTopSpinBox");
        numberMarginTopSpinBox->setMaximum(999);

        horizontalLayout_10->addWidget(numberMarginTopSpinBox);

        numberMarginRightSpinBox = new QSpinBox(groupBox_3);
        numberMarginRightSpinBox->setObjectName("numberMarginRightSpinBox");
        numberMarginRightSpinBox->setMaximum(999);

        horizontalLayout_10->addWidget(numberMarginRightSpinBox);

        numberMarginBottomSpinBox = new QSpinBox(groupBox_3);
        numberMarginBottomSpinBox->setObjectName("numberMarginBottomSpinBox");
        numberMarginBottomSpinBox->setMaximum(999);

        horizontalLayout_10->addWidget(numberMarginBottomSpinBox);


        verticalLayout_8->addLayout(horizontalLayout_10);


        gridLayout_6->addLayout(verticalLayout_8, 1, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayoutNumColor = new QHBoxLayout();
        horizontalLayoutNumColor->setObjectName("horizontalLayoutNumColor");
        label = new QLabel(groupBox_3);
        label->setObjectName("label");

        horizontalLayoutNumColor->addWidget(label);

        numberColorPushButton = new QPushButton(groupBox_3);
        numberColorPushButton->setObjectName("numberColorPushButton");
        numberColorPushButton->setFocusPolicy(Qt::NoFocus);

        horizontalLayoutNumColor->addWidget(numberColorPushButton);


        verticalLayout_2->addLayout(horizontalLayoutNumColor);

        horizontalLayoutNumSize = new QHBoxLayout();
        horizontalLayoutNumSize->setObjectName("horizontalLayoutNumSize");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        horizontalLayoutNumSize->addWidget(label_2);

        numberSizeSpinBox = new QSpinBox(groupBox_3);
        numberSizeSpinBox->setObjectName("numberSizeSpinBox");
        numberSizeSpinBox->setMinimum(1);
        numberSizeSpinBox->setMaximum(999);
        numberSizeSpinBox->setValue(10);

        horizontalLayoutNumSize->addWidget(numberSizeSpinBox);


        verticalLayout_2->addLayout(horizontalLayoutNumSize);

        horizontalLayoutAlignment = new QHBoxLayout();
        horizontalLayoutAlignment->setObjectName("horizontalLayoutAlignment");
        numberAlignmentLabel = new QLabel(groupBox_3);
        numberAlignmentLabel->setObjectName("numberAlignmentLabel");

        horizontalLayoutAlignment->addWidget(numberAlignmentLabel);

        numberAlignmentComboBox = new QComboBox(groupBox_3);
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->addItem(QString());
        numberAlignmentComboBox->setObjectName("numberAlignmentComboBox");

        horizontalLayoutAlignment->addWidget(numberAlignmentComboBox);


        verticalLayout_2->addLayout(horizontalLayoutAlignment);


        gridLayout_6->addLayout(verticalLayout_2, 0, 0, 1, 1);


        gridLayout_10->addWidget(groupBox_3, 1, 0, 2, 2);

        groupBox_7 = new QGroupBox(tabCount);
        groupBox_7->setObjectName("groupBox_7");
        verticalLayout_20 = new QVBoxLayout(groupBox_7);
        verticalLayout_20->setObjectName("verticalLayout_20");
        verticalLayout_19 = new QVBoxLayout();
        verticalLayout_19->setObjectName("verticalLayout_19");
        newIconRoundRadioButton = new QRadioButton(groupBox_7);
        newIndicatorTypeGroup = new QButtonGroup(PreferencesDialog);
        newIndicatorTypeGroup->setObjectName("newIndicatorTypeGroup");
        newIndicatorTypeGroup->addButton(newIconRoundRadioButton);
        newIconRoundRadioButton->setObjectName("newIconRoundRadioButton");

        verticalLayout_19->addWidget(newIconRoundRadioButton);

        newIconStarRadioButton = new QRadioButton(groupBox_7);
        newIndicatorTypeGroup->addButton(newIconStarRadioButton);
        newIconStarRadioButton->setObjectName("newIconStarRadioButton");

        verticalLayout_19->addWidget(newIconStarRadioButton);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        newShadeRadioButton = new QRadioButton(groupBox_7);
        newIndicatorTypeGroup->addButton(newShadeRadioButton);
        newShadeRadioButton->setObjectName("newShadeRadioButton");
        newShadeRadioButton->setChecked(true);

        horizontalLayout_15->addWidget(newShadeRadioButton);

        newShadeColorPushButton = new QPushButton(groupBox_7);
        newShadeColorPushButton->setObjectName("newShadeColorPushButton");

        horizontalLayout_15->addWidget(newShadeColorPushButton);


        verticalLayout_19->addLayout(horizontalLayout_15);


        verticalLayout_20->addLayout(verticalLayout_19);


        gridLayout_10->addWidget(groupBox_7, 1, 2, 1, 2);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_9, 1, 4, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 104, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer_8, 3, 0, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 64, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer_9, 2, 2, 1, 1);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_10, 0, 4, 1, 1);

        specialOptionsGroupBox = new QGroupBox(tabCount);
        specialOptionsGroupBox->setObjectName("specialOptionsGroupBox");
        gridLayout_8 = new QGridLayout(specialOptionsGroupBox);
        gridLayout_8->setObjectName("gridLayout_8");
        apiCountMethod = new QCheckBox(specialOptionsGroupBox);
        apiCountMethod->setObjectName("apiCountMethod");

        gridLayout_8->addWidget(apiCountMethod, 0, 0, 1, 1);

        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_10, 1, 0, 1, 1);


        gridLayout_10->addWidget(specialOptionsGroupBox, 0, 2, 1, 2);

        tabWidget->addTab(tabCount, QString());
        tabApps = new QWidget();
        tabApps->setObjectName("tabApps");
        gridLayout_11 = new QGridLayout(tabApps);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        groupBox_2 = new QGroupBox(tabApps);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_5 = new QGridLayout(groupBox_2);
        gridLayout_5->setObjectName("gridLayout_5");
        verticalLayout_18 = new QVBoxLayout();
        verticalLayout_18->setObjectName("verticalLayout_18");
        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        closeAppLineEdit = new QLineEdit(groupBox_2);
        closeAppLineEdit->setObjectName("closeAppLineEdit");

        horizontalLayout_12->addWidget(closeAppLineEdit);

        closeBrowseButton = new QPushButton(groupBox_2);
        closeBrowseButton->setObjectName("closeBrowseButton");

        horizontalLayout_12->addWidget(closeBrowseButton);


        verticalLayout_18->addLayout(horizontalLayout_12);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        horizontalLayout_9->addWidget(label_5);

        closeAppArgsLineEdit = new QLineEdit(groupBox_2);
        closeAppArgsLineEdit->setObjectName("closeAppArgsLineEdit");

        horizontalLayout_9->addWidget(closeAppArgsLineEdit);


        verticalLayout_18->addLayout(horizontalLayout_9);


        gridLayout_5->addLayout(verticalLayout_18, 0, 0, 1, 1);


        gridLayout_9->addWidget(groupBox_2, 1, 0, 1, 1);

        groupBox = new QGroupBox(tabApps);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalLayout_17 = new QVBoxLayout();
        verticalLayout_17->setObjectName("verticalLayout_17");
        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        startAppLineEdit = new QLineEdit(groupBox);
        startAppLineEdit->setObjectName("startAppLineEdit");

        horizontalLayout_14->addWidget(startAppLineEdit);

        startBrowseButton = new QPushButton(groupBox);
        startBrowseButton->setObjectName("startBrowseButton");

        horizontalLayout_14->addWidget(startBrowseButton);


        verticalLayout_17->addLayout(horizontalLayout_14);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        horizontalLayout_5->addWidget(label_6);

        startAppArgsLineEdit = new QLineEdit(groupBox);
        startAppArgsLineEdit->setObjectName("startAppArgsLineEdit");

        horizontalLayout_5->addWidget(startAppArgsLineEdit);


        verticalLayout_17->addLayout(horizontalLayout_5);


        gridLayout_2->addLayout(verticalLayout_17, 0, 0, 1, 1);


        gridLayout_9->addWidget(groupBox, 0, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_7, 2, 0, 1, 1);


        gridLayout_11->addLayout(gridLayout_9, 0, 0, 1, 1);

        tabWidget->addTab(tabApps, QString());
        tabMail = new QWidget();
        tabMail->setObjectName("tabMail");
        gridLayout_4 = new QGridLayout(tabMail);
        gridLayout_4->setObjectName("gridLayout_4");
        label_4 = new QLabel(tabMail);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        gridLayout_4->addWidget(label_4, 0, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(265, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_6, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 464, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 1, 0, 1, 1);

        tabWidget->addTab(tabMail, QString());
        tabShortcuts = new QWidget();
        tabShortcuts->setObjectName("tabShortcuts");
        gridLayout_7 = new QGridLayout(tabShortcuts);
        gridLayout_7->setObjectName("gridLayout_7");
        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setObjectName("verticalLayout_16");
        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        label_8 = new QLabel(tabShortcuts);
        label_8->setObjectName("label_8");

        horizontalLayout_16->addWidget(label_8);

        currentShowHideShortcut = new QLabel(tabShortcuts);
        currentShowHideShortcut->setObjectName("currentShowHideShortcut");

        horizontalLayout_16->addWidget(currentShowHideShortcut);


        horizontalLayout_18->addLayout(horizontalLayout_16);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_13);


        verticalLayout_16->addLayout(horizontalLayout_18);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        label_7 = new QLabel(tabShortcuts);
        label_7->setObjectName("label_7");

        horizontalLayout_17->addWidget(label_7);

        showHideKeySequenceEdit = new QKeySequenceEdit(tabShortcuts);
        showHideKeySequenceEdit->setObjectName("showHideKeySequenceEdit");

        horizontalLayout_17->addWidget(showHideKeySequenceEdit);

        clearShowHideShortcutPushButton = new QPushButton(tabShortcuts);
        clearShowHideShortcutPushButton->setObjectName("clearShowHideShortcutPushButton");

        horizontalLayout_17->addWidget(clearShowHideShortcutPushButton);


        verticalLayout_16->addLayout(horizontalLayout_17);


        gridLayout_7->addLayout(verticalLayout_16, 0, 0, 1, 1);

        verticalSpacer_11 = new QSpacerItem(20, 297, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_7->addItem(verticalSpacer_11, 1, 0, 1, 1);

        tabWidget->addTab(tabShortcuts, QString());
        tabDebug = new QWidget();
        tabDebug->setObjectName("tabDebug");
        gridLayout_3 = new QGridLayout(tabDebug);
        gridLayout_3->setObjectName("gridLayout_3");
        debugWindowCheckBox = new QCheckBox(tabDebug);
        debugWindowCheckBox->setObjectName("debugWindowCheckBox");

        gridLayout_3->addWidget(debugWindowCheckBox, 0, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(358, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_7, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 485, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_3, 1, 0, 1, 1);

        tabWidget->addTab(tabDebug, QString());

        verticalLayout_24->addWidget(tabWidget);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalSpacer_4 = new QSpacerItem(369, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_4);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        cancelPushButton = new QPushButton(PreferencesDialog);
        cancelPushButton->setObjectName("cancelPushButton");

        horizontalLayout_7->addWidget(cancelPushButton);

        savePushButton = new QPushButton(PreferencesDialog);
        savePushButton->setObjectName("savePushButton");

        horizontalLayout_7->addWidget(savePushButton);


        horizontalLayout_13->addLayout(horizontalLayout_7);


        verticalLayout_24->addLayout(horizontalLayout_13);


        gridLayout_14->addLayout(verticalLayout_24, 0, 0, 1, 1);


        retranslateUi(PreferencesDialog);

        tabWidget->setCurrentIndex(0);
        numberAlignmentComboBox->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(PreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *PreferencesDialog)
    {
        PreferencesDialog->setWindowTitle(QCoreApplication::translate("PreferencesDialog", "SysTray-X Preferences", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("PreferencesDialog", "Minimize", nullptr));
        defaultMinimizeRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default minimize", nullptr));
        minimizeMethod1RadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize to tray", nullptr));
        minimizeMethod2RadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize to tray, method 2", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("PreferencesDialog", "Icon", nullptr));
        defaultMinimizeIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default minimize", nullptr));
        minimizeTrayIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize to tray", nullptr));
        positionGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Position", nullptr));
        correctWinPosCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Correct window positions", nullptr));
        noTitlebarCorrectionRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "No titlebar correction", nullptr));
        addTitlebarCorrectionRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Add titlebar size", nullptr));
        subtractTitlebarCorrectionRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Subtract titlebar size", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("PreferencesDialog", "Close", nullptr));
        defaultCloseWindowsRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default close", nullptr));
        minimizeMainTrayCloseChildrenWindowsRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize main to tray, close children", nullptr));
        minimizeAllTrayWindowsRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize all windows to tray", nullptr));
        minimizeMainCloseChildrenWindowsRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize main, close children", nullptr));
        minimizeAllWindowsRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Minimize all windows", nullptr));
        groupBox_9->setTitle(QCoreApplication::translate("PreferencesDialog", "Startup", nullptr));
        startDefaultRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default startup", nullptr));
        startMinimizedRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Start application minimized", nullptr));
        startDockedRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Start application in tray", nullptr));
        restorePositionscheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Restore startup positions", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabWindows), QCoreApplication::translate("PreferencesDialog", "Windows", nullptr));
        defaultIconGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Default icon", nullptr));
        iconGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Icon", nullptr));
        defaultIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default Thunderbird", nullptr));
        lookThroughDefaultIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Lookthrough icon", nullptr));
        customDefaultIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Custom icon", nullptr));
        defaultImageLabel->setText(QString());
        chooseCustomDefaultIconButton->setText(QCoreApplication::translate("PreferencesDialog", "Choose", nullptr));
        hideDefaultIconCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "KDE integration (Hide)", nullptr));
        iconTypeGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Mail notification icon", nullptr));
        groupBox_8->setTitle(QCoreApplication::translate("PreferencesDialog", "Icon", nullptr));
        blankIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Blank icon", nullptr));
        newMailIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "New mail icon", nullptr));
        customIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Custom icon", nullptr));
        imageLabel->setText(QString());
        chooseCustomButton->setText(QCoreApplication::translate("PreferencesDialog", "Choose", nullptr));
        noIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "No icon", nullptr));
        tbIconRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Default Thunderbird", nullptr));
        invertIconCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Invert icon", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabIcon), QCoreApplication::translate("PreferencesDialog", "Icon", nullptr));
        showNumberCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Show message count", nullptr));
        showNewCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Show new indicator", nullptr));
        label_3->setText(QCoreApplication::translate("PreferencesDialog", "Startup delay", nullptr));
        countTypeGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Count type", nullptr));
        unreadRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Unread", nullptr));
        newRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "New", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("PreferencesDialog", "Number properties", nullptr));
        numberMarginsLabel->setText(QCoreApplication::translate("PreferencesDialog", "Margins (left, top, right, bottom):", nullptr));
        label->setText(QCoreApplication::translate("PreferencesDialog", "Number color", nullptr));
        numberColorPushButton->setText(QString());
        label_2->setText(QCoreApplication::translate("PreferencesDialog", "Number size", nullptr));
        numberAlignmentLabel->setText(QCoreApplication::translate("PreferencesDialog", "Alignment", nullptr));
        numberAlignmentComboBox->setItemText(0, QCoreApplication::translate("PreferencesDialog", "Top left", nullptr));
        numberAlignmentComboBox->setItemText(1, QCoreApplication::translate("PreferencesDialog", "Top centre", nullptr));
        numberAlignmentComboBox->setItemText(2, QCoreApplication::translate("PreferencesDialog", "Top right", nullptr));
        numberAlignmentComboBox->setItemText(3, QCoreApplication::translate("PreferencesDialog", "Middle left", nullptr));
        numberAlignmentComboBox->setItemText(4, QCoreApplication::translate("PreferencesDialog", "Middle centre", nullptr));
        numberAlignmentComboBox->setItemText(5, QCoreApplication::translate("PreferencesDialog", "Middle right", nullptr));
        numberAlignmentComboBox->setItemText(6, QCoreApplication::translate("PreferencesDialog", "Bottom left", nullptr));
        numberAlignmentComboBox->setItemText(7, QCoreApplication::translate("PreferencesDialog", "Bottom centre", nullptr));
        numberAlignmentComboBox->setItemText(8, QCoreApplication::translate("PreferencesDialog", "Bottom right", nullptr));

        groupBox_7->setTitle(QCoreApplication::translate("PreferencesDialog", "New indicator", nullptr));
        newIconRoundRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Icon round", nullptr));
        newIconStarRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Icon star", nullptr));
        newShadeRadioButton->setText(QCoreApplication::translate("PreferencesDialog", "Shade", nullptr));
        newShadeColorPushButton->setText(QString());
        specialOptionsGroupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Special options", nullptr));
        apiCountMethod->setText(QCoreApplication::translate("PreferencesDialog", "API count method", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabCount), QCoreApplication::translate("PreferencesDialog", "Count", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("PreferencesDialog", "Close application", nullptr));
        closeBrowseButton->setText(QCoreApplication::translate("PreferencesDialog", "Browse...", nullptr));
        label_5->setText(QCoreApplication::translate("PreferencesDialog", "Arguments:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Start application", nullptr));
        startBrowseButton->setText(QCoreApplication::translate("PreferencesDialog", "Browse...", nullptr));
        label_6->setText(QCoreApplication::translate("PreferencesDialog", "Arguments:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabApps), QCoreApplication::translate("PreferencesDialog", "Apps", nullptr));
        label_4->setText(QCoreApplication::translate("PreferencesDialog", "Use the preferences dialog in Thunderbird to select the accounts and folders", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabMail), QCoreApplication::translate("PreferencesDialog", "Mail", nullptr));
        label_8->setText(QCoreApplication::translate("PreferencesDialog", "Current show / hide shortcut:", nullptr));
        label_7->setText(QCoreApplication::translate("PreferencesDialog", "New show / hide shortcut:", nullptr));
        showHideKeySequenceEdit->setKeySequence(QString());
        clearShowHideShortcutPushButton->setText(QCoreApplication::translate("PreferencesDialog", "Clear", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabShortcuts), QCoreApplication::translate("PreferencesDialog", "Shortcuts", nullptr));
        debugWindowCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Display debug window", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDebug), QCoreApplication::translate("PreferencesDialog", "Debug", nullptr));
        cancelPushButton->setText(QCoreApplication::translate("PreferencesDialog", "Cancel", nullptr));
        savePushButton->setText(QCoreApplication::translate("PreferencesDialog", "Save", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PreferencesDialog: public Ui_PreferencesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFERENCES_H
