/****************************************************************************
** Meta object code from reading C++ file 'preferences.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/preferences.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'preferences.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PreferencesE_t {};
} // unnamed namespace

template <> constexpr inline auto Preferences::qt_create_metaobjectdata<qt_meta_tag_ZN11PreferencesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Preferences",
        "signalConsole",
        "",
        "message",
        "signalMinimizeTypeChange",
        "signalCloseTypeChange",
        "signalMinimizeIconTypeChange",
        "signalStartupTypeChange",
        "signalWindowPositionsCorrectionChange",
        "signalWindowPositionsCorrectionTypeChange",
        "signalRestoreWindowPositionsChange",
        "signalDefaultIconTypeChange",
        "signalDefaultIconDataChange",
        "signalHideDefaultIconChange",
        "signalIconTypeChange",
        "signalIconDataChange",
        "signalInvertIconChange",
        "signalShowNumberChange",
        "signalShowNewIndicatorChange",
        "signalCountTypeChange",
        "signalStartupDelayChange",
        "signalNumberColorChange",
        "signalNumberSizeChange",
        "signalNumberAlignmentChange",
        "signalNumberMarginsChange",
        "signalNewIndicatorTypeChange",
        "signalNewShadeColorChange",
        "signalDebugChange",
        "signalStartAppChange",
        "signalStartAppArgsChange",
        "signalCloseAppChange",
        "signalCloseAppArgsChange",
        "signalApiCountMethodChange",
        "signalShowHideShortcutChange",
        "signalNewMessageFromsChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalConsole'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'signalMinimizeTypeChange'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalCloseTypeChange'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalMinimizeIconTypeChange'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStartupTypeChange'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalWindowPositionsCorrectionChange'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalWindowPositionsCorrectionTypeChange'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalRestoreWindowPositionsChange'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalDefaultIconTypeChange'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalDefaultIconDataChange'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalHideDefaultIconChange'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalIconTypeChange'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalIconDataChange'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalInvertIconChange'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalShowNumberChange'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalShowNewIndicatorChange'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalCountTypeChange'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStartupDelayChange'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberColorChange'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberSizeChange'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberAlignmentChange'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberMarginsChange'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNewIndicatorTypeChange'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNewShadeColorChange'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalDebugChange'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStartAppChange'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStartAppArgsChange'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalCloseAppChange'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalCloseAppArgsChange'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalApiCountMethodChange'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalShowHideShortcutChange'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNewMessageFromsChange'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Preferences, qt_meta_tag_ZN11PreferencesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Preferences::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PreferencesE_t>.metaTypes,
    nullptr
} };

void Preferences::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Preferences *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalConsole((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->signalMinimizeTypeChange(); break;
        case 2: _t->signalCloseTypeChange(); break;
        case 3: _t->signalMinimizeIconTypeChange(); break;
        case 4: _t->signalStartupTypeChange(); break;
        case 5: _t->signalWindowPositionsCorrectionChange(); break;
        case 6: _t->signalWindowPositionsCorrectionTypeChange(); break;
        case 7: _t->signalRestoreWindowPositionsChange(); break;
        case 8: _t->signalDefaultIconTypeChange(); break;
        case 9: _t->signalDefaultIconDataChange(); break;
        case 10: _t->signalHideDefaultIconChange(); break;
        case 11: _t->signalIconTypeChange(); break;
        case 12: _t->signalIconDataChange(); break;
        case 13: _t->signalInvertIconChange(); break;
        case 14: _t->signalShowNumberChange(); break;
        case 15: _t->signalShowNewIndicatorChange(); break;
        case 16: _t->signalCountTypeChange(); break;
        case 17: _t->signalStartupDelayChange(); break;
        case 18: _t->signalNumberColorChange(); break;
        case 19: _t->signalNumberSizeChange(); break;
        case 20: _t->signalNumberAlignmentChange(); break;
        case 21: _t->signalNumberMarginsChange(); break;
        case 22: _t->signalNewIndicatorTypeChange(); break;
        case 23: _t->signalNewShadeColorChange(); break;
        case 24: _t->signalDebugChange(); break;
        case 25: _t->signalStartAppChange(); break;
        case 26: _t->signalStartAppArgsChange(); break;
        case 27: _t->signalCloseAppChange(); break;
        case 28: _t->signalCloseAppArgsChange(); break;
        case 29: _t->signalApiCountMethodChange(); break;
        case 30: _t->signalShowHideShortcutChange(); break;
        case 31: _t->signalNewMessageFromsChange(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)(QString )>(_a, &Preferences::signalConsole, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalMinimizeTypeChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalCloseTypeChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalMinimizeIconTypeChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalStartupTypeChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalWindowPositionsCorrectionChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalWindowPositionsCorrectionTypeChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalRestoreWindowPositionsChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalDefaultIconTypeChange, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalDefaultIconDataChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalHideDefaultIconChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalIconTypeChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalIconDataChange, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalInvertIconChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalShowNumberChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalShowNewIndicatorChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalCountTypeChange, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalStartupDelayChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNumberColorChange, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNumberSizeChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNumberAlignmentChange, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNumberMarginsChange, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNewIndicatorTypeChange, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNewShadeColorChange, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalDebugChange, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalStartAppChange, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalStartAppArgsChange, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalCloseAppChange, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalCloseAppArgsChange, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalApiCountMethodChange, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalShowHideShortcutChange, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)()>(_a, &Preferences::signalNewMessageFromsChange, 31))
            return;
    }
}

const QMetaObject *Preferences::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Preferences::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Preferences::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void Preferences::signalConsole(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Preferences::signalMinimizeTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Preferences::signalCloseTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Preferences::signalMinimizeIconTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Preferences::signalStartupTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Preferences::signalWindowPositionsCorrectionChange()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Preferences::signalWindowPositionsCorrectionTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Preferences::signalRestoreWindowPositionsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Preferences::signalDefaultIconTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Preferences::signalDefaultIconDataChange()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Preferences::signalHideDefaultIconChange()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Preferences::signalIconTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Preferences::signalIconDataChange()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Preferences::signalInvertIconChange()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Preferences::signalShowNumberChange()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Preferences::signalShowNewIndicatorChange()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Preferences::signalCountTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Preferences::signalStartupDelayChange()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Preferences::signalNumberColorChange()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Preferences::signalNumberSizeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Preferences::signalNumberAlignmentChange()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Preferences::signalNumberMarginsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Preferences::signalNewIndicatorTypeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Preferences::signalNewShadeColorChange()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Preferences::signalDebugChange()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Preferences::signalStartAppChange()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Preferences::signalStartAppArgsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Preferences::signalCloseAppChange()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Preferences::signalCloseAppArgsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Preferences::signalApiCountMethodChange()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Preferences::signalShowHideShortcutChange()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Preferences::signalNewMessageFromsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}
QT_WARNING_POP
