/****************************************************************************
** Meta object code from reading C++ file 'systrayxstatusnotifier.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../SysTray-X/SysTray-X-app/systrayxstatusnotifier.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systrayxstatusnotifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22SysTrayXStatusNotifierE_t {};
} // unnamed namespace

template <> constexpr inline auto SysTrayXStatusNotifier::qt_create_metaobjectdata<qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SysTrayXStatusNotifier",
        "signalShowHide",
        "",
        "slotMailCount",
        "unread_mail",
        "new_mail",
        "slotDefaultIconTypeChange",
        "slotDefaultIconDataChange",
        "slotHideDefaultIconChange",
        "slotIconTypeChange",
        "slotIconDataChange",
        "slotInvertIconChange",
        "slotShowNumberChange",
        "slotShowNewIndicatorChange",
        "slotNumberColorChange",
        "slotNumberSizeChange",
        "slotNumberAlignmentChange",
        "slotNumberMarginsChange",
        "slotNewIndicatorTypeChange",
        "slotNewShadeColorChange",
        "slotActivateRequested",
        "active",
        "QPoint",
        "pos",
        "slotSecondaryActivateRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalShowHide'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMailCount'
        QtMocHelpers::SlotData<void(int, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'slotDefaultIconTypeChange'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefaultIconDataChange'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHideDefaultIconChange'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIconTypeChange'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIconDataChange'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvertIconChange'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowNumberChange'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowNewIndicatorChange'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberColorChange'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberSizeChange'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberAlignmentChange'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNumberMarginsChange'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewIndicatorTypeChange'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewShadeColorChange'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivateRequested'
        QtMocHelpers::SlotData<void(bool, const QPoint &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'slotSecondaryActivateRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SysTrayXStatusNotifier, qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SysTrayXStatusNotifier::staticMetaObject = { {
    QMetaObject::SuperData::link<KStatusNotifierItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>.metaTypes,
    nullptr
} };

void SysTrayXStatusNotifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SysTrayXStatusNotifier *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalShowHide(); break;
        case 1: _t->slotMailCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->slotDefaultIconTypeChange(); break;
        case 3: _t->slotDefaultIconDataChange(); break;
        case 4: _t->slotHideDefaultIconChange(); break;
        case 5: _t->slotIconTypeChange(); break;
        case 6: _t->slotIconDataChange(); break;
        case 7: _t->slotInvertIconChange(); break;
        case 8: _t->slotShowNumberChange(); break;
        case 9: _t->slotShowNewIndicatorChange(); break;
        case 10: _t->slotNumberColorChange(); break;
        case 11: _t->slotNumberSizeChange(); break;
        case 12: _t->slotNumberAlignmentChange(); break;
        case 13: _t->slotNumberMarginsChange(); break;
        case 14: _t->slotNewIndicatorTypeChange(); break;
        case 15: _t->slotNewShadeColorChange(); break;
        case 16: _t->slotActivateRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 17: _t->slotSecondaryActivateRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SysTrayXStatusNotifier::*)()>(_a, &SysTrayXStatusNotifier::signalShowHide, 0))
            return;
    }
}

const QMetaObject *SysTrayXStatusNotifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SysTrayXStatusNotifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22SysTrayXStatusNotifierE_t>.strings))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int SysTrayXStatusNotifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void SysTrayXStatusNotifier::signalShowHide()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
